==> physx-jni-0.4.1-sources.jar: physx/physics/PxActor.java <==
package physx.physics;

import physx.common.PxBase;
import physx.common.PxBounds3;

public class PxActor extends PxBase {

    protected PxActor() { }

    public static PxActor wrapPointer(long address) {
        return address != 0L ? new PxActor(address) : null;
    }
    
    protected PxActor(long address) {
        super(address);
    }

    // Functions

    /**
     * @return WebIDL type: {@link PxActorTypeEnum} [enum]
     */
    public int getType() {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        return _getType(address);
    }
    private static native int _getType(long address);

    /**
     * @return WebIDL type: {@link PxScene}
     */
    public PxScene getScene() {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        return PxScene.wrapPointer(_getScene(address));
    }
    private static native long _getScene(long address);

    /**
     * @param name WebIDL type: DOMString
     */
    public void setName(String name) {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        _setName(address, name);
    }
    private static native void _setName(long address, String name);

    /**
     * @return WebIDL type: DOMString [Const]
     */
    public String getName() {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        return _getName(address);
    }
    private static native String _getName(long address);

    /**
     * @return WebIDL type: {@link PxBounds3} [Value]
     */
    public PxBounds3 getWorldBounds() {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        return PxBounds3.wrapPointer(_getWorldBounds(address));
    }
    private static native long _getWorldBounds(long address);

    /**
     * @param inflation WebIDL type: float
     * @return WebIDL type: {@link PxBounds3} [Value]
     */
    public PxBounds3 getWorldBounds(float inflation) {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        return PxBounds3.wrapPointer(_getWorldBounds(address, inflation));
    }
    private static native long _getWorldBounds(long address, float inflation);

    /**
     * @param flags WebIDL type: {@link PxActorFlags} [Ref]
     */
    public void setActorFlags(PxActorFlags flags) {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        _setActorFlags(address, flags.getAddress());
    }
    private static native void _setActorFlags(long address, long flags);

    /**
     * @return WebIDL type: {@link PxActorFlags} [Value]
     */
    public PxActorFlags getActorFlags() {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        return PxActorFlags.wrapPointer(_getActorFlags(address));
    }
    private static native long _getActorFlags(long address);

    /**
     * @param dominanceGroup WebIDL type: octet
     */
    public void setDominanceGroup(byte dominanceGroup) {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        _setDominanceGroup(address, dominanceGroup);
    }
    private static native void _setDominanceGroup(long address, byte dominanceGroup);

    /**
     * @return WebIDL type: octet
     */
    public byte getDominanceGroup() {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        return _getDominanceGroup(address);
    }
    private static native byte _getDominanceGroup(long address);

    /**
     * @param inClient WebIDL type: octet
     */
    public void setOwnerClient(byte inClient) {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        _setOwnerClient(address, inClient);
    }
    private static native void _setOwnerClient(long address, byte inClient);

    /**
     * @return WebIDL type: octet
     */
    public byte getOwnerClient() {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        return _getOwnerClient(address);
    }
    private static native byte _getOwnerClient(long address);

}

==> physx-jni-0.4.4-sources.jar: physx/physics/PxActor.java <==
package physx.physics;

import physx.common.PxBase;
import physx.common.PxBounds3;

public class PxActor extends PxBase {

    protected PxActor() { }

    public static PxActor wrapPointer(long address) {
        return address != 0L ? new PxActor(address) : null;
    }
    
    protected PxActor(long address) {
        super(address);
    }

    // Functions

    /**
     * @return WebIDL type: {@link PxActorTypeEnum} [enum]
     */
    public int getType() {
        checkNotNull();
        return _getType(address);
    }
    private static native int _getType(long address);

    /**
     * @return WebIDL type: {@link PxScene}
     */
    public PxScene getScene() {
        checkNotNull();
        return PxScene.wrapPointer(_getScene(address));
    }
    private static native long _getScene(long address);

    /**
     * @param name WebIDL type: DOMString
     */
    public void setName(String name) {
        checkNotNull();
        _setName(address, name);
    }
    private static native void _setName(long address, String name);

    /**
     * @return WebIDL type: DOMString [Const]
     */
    public String getName() {
        checkNotNull();
        return _getName(address);
    }
    private static native String _getName(long address);

    /**
     * @return WebIDL type: {@link PxBounds3} [Value]
     */
    public PxBounds3 getWorldBounds() {
        checkNotNull();
        return PxBounds3.wrapPointer(_getWorldBounds(address));
    }
    private static native long _getWorldBounds(long address);

    /**
     * @param inflation WebIDL type: float
     * @return WebIDL type: {@link PxBounds3} [Value]
     */
    public PxBounds3 getWorldBounds(float inflation) {
        checkNotNull();
        return PxBounds3.wrapPointer(_getWorldBounds(address, inflation));
    }
    private static native long _getWorldBounds(long address, float inflation);

    /**
     * @param flags WebIDL type: {@link PxActorFlags} [Ref]
     */
    public void setActorFlags(PxActorFlags flags) {
        checkNotNull();
        _setActorFlags(address, flags.getAddress());
    }
    private static native void _setActorFlags(long address, long flags);

    /**
     * @return WebIDL type: {@link PxActorFlags} [Value]
     */
    public PxActorFlags getActorFlags() {
        checkNotNull();
        return PxActorFlags.wrapPointer(_getActorFlags(address));
    }
    private static native long _getActorFlags(long address);

    /**
     * @param dominanceGroup WebIDL type: octet
     */
    public void setDominanceGroup(byte dominanceGroup) {
        checkNotNull();
        _setDominanceGroup(address, dominanceGroup);
    }
    private static native void _setDominanceGroup(long address, byte dominanceGroup);

    /**
     * @return WebIDL type: octet
     */
    public byte getDominanceGroup() {
        checkNotNull();
        return _getDominanceGroup(address);
    }
    private static native byte _getDominanceGroup(long address);

    /**
     * @param inClient WebIDL type: octet
     */
    public void setOwnerClient(byte inClient) {
        checkNotNull();
        _setOwnerClient(address, inClient);
    }
    private static native void _setOwnerClient(long address, byte inClient);

    /**
     * @return WebIDL type: octet
     */
    public byte getOwnerClient() {
        checkNotNull();
        return _getOwnerClient(address);
    }
    private static native byte _getOwnerClient(long address);

}
